@@ -7,8 +7,6 @@
  */
 
 
-#include "Qt4Compat.h" // qHtmlEscape()
-
 #include "BreadcrumbNavigator.h"
 #include "DirInfo.h"
 #include "Logger.h"
@@ -66,6 +64,10 @@ void BreadcrumbNavigator::fillBreadcrumbs( FileInfo * item )
     QString basePath;
 
     FileInfo * toplevel = item->tree()->firstToplevel();
+
+    if ( ! toplevel )
+        return;
+
     splitBasePath( toplevel->name(), basePath, name );
 
     if ( ! basePath.isEmpty() )
@@ -113,13 +115,13 @@ QString BreadcrumbNavigator::html() const
         {
             if ( crumb.url.isEmpty() )
             {
-                html += qHtmlEscape( name );
+                html += name.toHtmlEscaped();
             }
             else
             {
                 html += QString( "<a href=\"%1\">%2</a>" )
                     .arg( crumb.url )
-                    .arg( qHtmlEscape( name ) );
+                    .arg( name.toHtmlEscaped() );
             }
 
             if ( ! name.endsWith( "/" ) )
@@ -217,7 +219,7 @@ void BreadcrumbNavigator::splitBasePath( const QString & path,
 
     if ( path != "/" && path.contains( "/" ) )
     {
-        QStringList components = path.split( "/", QString::SkipEmptyParts );
+        QStringList components = path.split( "/", Qt::SkipEmptyParts );
 
         if ( ! components.empty() )
             name_ret = components.takeLast();
