@@ -61,12 +61,18 @@ DirInfo::DirInfo( DirTree *	  tree,
 		  const QString & filenameWithoutPath,
 		  mode_t	  mode,
 		  FileSize	  size,
+                  bool            withUidGidPerm,
+                  uid_t           uid,
+                  gid_t           gid,
 		  time_t	  mtime )
     : FileInfo( tree,
 		parent,
 		filenameWithoutPath,
 		mode,
 		size,
+                withUidGidPerm,
+                uid,
+                gid,
 		mtime )
 {
     init();
@@ -190,6 +196,8 @@ void DirInfo::deleteEmptyDotEntry()
 {
     if ( ! _dotEntry->firstChild() && ! _dotEntry->hasAtticChildren() )
     {
+        // logDebug() << "Deleting dot entry for " << this << endl;
+
 	delete _dotEntry;
 	_dotEntry = 0;
 
@@ -216,6 +224,8 @@ void DirInfo::deleteEmptyAttic()
 {
     if ( _attic && ! _attic->firstChild() )
     {
+        // logDebug() << "Deleting attic for " << this << endl;
+
 	delete _attic;
 	_attic = 0;
     }
