@@ -9,6 +9,7 @@
 
 #include <dirent.h>     // struct dirent
 #include <fcntl.h>	// AT_ constants (fstatat() flags)
+#include <unistd.h>     // R_OK, X_OK
 
 #include <QMutableListIterator>
 #include <QMultiMap>
@@ -105,43 +106,35 @@ void DirReadJob::deletingChild( FileInfo *deletedChild )
 
 bool DirReadJob::crossingFilesystems( DirInfo * parent, DirInfo * child )
 {
+    // Simple (and most common) case: Compare the device numbers (dev_t)
+
     if ( parent->device() == child->device() )
-	return false;
+	return false; // Not crossing filesystems
 
-    QString childDevice	 = device( child );
-    QString parentDevice = device( parent->findNearestMountPoint() );
+    // Less common case: Different device numbers. So let's also find the
+    // nearest mount point from /proc/mounts and compare the device names
+    // (/dev/sda2 etc.).
+    //
+    // This is important both for Btrfs subvolumes that all have the same
+    // device name, and for a directory tree that was originally read from a
+    // cache file, but now a subtree is being read from disk (F6 key).
+    //
+    // See also https://github.com/shundhammer/qdirstat/issues/273
 
-    if ( childDevice.isEmpty() && parent->readState() == DirCached )
-    {
-	// A DirInfo from a cache file always has device number 0, so the
-	// initial check failed because of that. The child might still be a
-	// mount point, but since that path was not found in the list of known
-	// mount points from /proc/mounts or /etc/mtab, we assume that this was
-	// not the case.
-	//
-	// See also https://github.com/shundhammer/qdirstat/issues/114
+    QString parentDevice = device( parent );
+    QString childDevice  = device( child  );
 
-	return false;
-    }
-
-    if ( parentDevice.isEmpty() )
-	parentDevice = _tree->device();
-
-    bool crossing = true;
-
-    if ( ! parentDevice.isEmpty() && ! childDevice.isEmpty() )
-	crossing = parentDevice != childDevice;
+    bool crossing = ( parentDevice != childDevice );
 
     if ( crossing )
     {
-	logInfo() << "Filesystem boundary at mount point " << child
-		  << " on device " << ( childDevice.isEmpty() ? "<unknown>" : childDevice )
-		  << endl;
+        logInfo() << "Filesystem boundary at mount point " << child
+                  << " on device " << ( childDevice.isEmpty() ? "<unknown>" : childDevice )
+                  << endl;
     }
     else
     {
-	logInfo() << "Mount point " << child
-		  << " is still on the same device " << childDevice << endl;
+        logInfo() << child << " is still on the same device " << childDevice << endl;
     }
 
     return crossing;
@@ -156,8 +149,15 @@ QString DirReadJob::device( const DirInfo * dir ) const
     {
 	MountPoint * mountPoint = MountPoints::findByPath( dir->url() );
 
+        if ( ! mountPoint )
+            mountPoint = MountPoints::findNearestMountPoint( dir->url() );
+
 	if ( mountPoint )
+        {
 	    device = mountPoint->device();
+
+            // logDebug() << "Found " << mountPoint << " for " << dir << endl;
+        }
     }
 
     return device;
@@ -509,6 +509,7 @@ bool LocalDirReadJob::readCacheFile( const QString & cacheFileName )
 		     << " for " << _dirName
 		     << endl;
 
+        cacheReadJob->reader()->setAborted();
 	delete cacheReadJob;
 
 	return false;
@@ -540,6 +541,7 @@ void LocalDirReadJob::handleLstatError( const QString & entryName )
     DirInfo *child = new DirInfo( _tree, _dir, entryName,
 				  0,   // mode
 				  0,   // size
+                                  false, 0, 0,  // withUidGid, uid, gid
 				  0 ); // mtime
     CHECK_NEW( child );
     child->finalizeLocal();
@@ -572,7 +574,7 @@ FileInfo * LocalDirReadJob::stat( const QString & url,
 
 	if ( parent && parent != tree->root() )
 	{
-	    QStringList components = url.split( "/", QString::SkipEmptyParts );
+	    QStringList components = url.split( "/", Qt::SkipEmptyParts );
 	    name = components.last();
 	}
 
@@ -618,6 +620,9 @@ FileInfo * LocalDirReadJob::stat( const QString & url,
 
 bool LocalDirReadJob::isNtfs()
 {
+    if ( ! MountPoints::hasNtfs() )
+        return false;
+
     if ( ! _checkedForNtfs )
     {
         _isNtfs         = false;
@@ -688,8 +693,7 @@ CacheReadJob::~CacheReadJob()
 }
 
 
-void
-CacheReadJob::read()
+void CacheReadJob::read()
 {
     /*
      * This will be called repeatedly from DirTree::timeSlicedRead() until
@@ -697,7 +701,10 @@ CacheReadJob::read()
      */
 
     if ( ! _reader )
+    {
 	finished();
+        return;
+    }
 
     // logDebug() << "Reading 1000 cache lines" << endl;
     _reader->read( 1000 );
@@ -836,7 +843,9 @@ void DirReadJobQueue::killAll( DirInfo * subtree, DirReadJob * exceptJob )
 
 void DirReadJobQueue::timeSlicedRead()
 {
-    if ( ! _queue.isEmpty() )
+    if ( _queue.isEmpty() )
+	_timer.stop();
+    else
 	_queue.first()->read();
 }
 
@@ -853,14 +862,8 @@ void DirReadJobQueue::jobFinishedNotify( DirReadJob *job )
 
     // The timer will start a new job when it fires.
 
-    if ( _queue.isEmpty() )	// No new job available - we're done.
-    {
-	_timer.stop();
-	// logDebug() << "No more jobs - finishing" << endl;
-
-	if ( _blocked.isEmpty() )
-	    emit finished();
-    }
+    if ( _queue.isEmpty() && _blocked.isEmpty() )	// No new job available - we're done.
+	emit finished();
 }
 
 
