@@ -8,8 +8,7 @@
 
 
 #include <QPalette>
-
-#include "Qt4Compat.h"
+#include <QGuiApplication>
 
 #include "DirTreeModel.h"
 #include "DirTree.h"
@@ -129,7 +128,7 @@ void DirTreeModel::writeSettings()
 
 bool DirTreeModel::usingDarkTheme()
 {
-    QColor background = qAppPalette().color( QPalette::Active, QPalette::Base );
+    QColor background = QGuiApplication::palette().color( QPalette::Active, QPalette::Base );
 
     return background.lightness() < 128; // 0 (black) .. 255 (white)
 }
@@ -436,7 +435,7 @@ QVariant DirTreeModel::data( const QModelIndex & index, int role ) const
 	case Qt::ForegroundRole: // Text color
 	    {
 		if ( item->isIgnored() || item->isAttic() )
-		    return qAppPalette().brush( QPalette::Disabled, QPalette::Foreground );
+		    return QGuiApplication::palette().brush( QPalette::Disabled, QPalette::WindowText );
 
 		if ( item->isDir() )
 		{
@@ -532,10 +531,8 @@ Qt::ItemFlags DirTreeModel::flags( const QModelIndex & index ) const
 
     Qt::ItemFlags baseFlags = Qt::ItemIsEnabled;
 
-#if (QT_VERSION >= QT_VERSION_CHECK( 5, 1, 0 ))
     if ( ! item->isDirInfo() )
 	baseFlags |= Qt::ItemNeverHasChildren;
-#endif
 
     // logDebug() << "Flags for " << index << endl;
     DataColumn col = DataColumns::fromViewCol( index.column() );
@@ -677,7 +674,7 @@ QVariant DirTreeModel::columnText( FileInfo * item, int col ) const
     if ( col == _readJobsCol && item->isBusy() )
 	return tr( "[%1 Read Jobs]" ).arg( item->pendingReadJobs() );
 
-    bool limitedInfo = item->isPseudoDir() || item->readState() == DirCached || item->isPkgInfo();
+    bool limitedInfo = item->isPseudoDir() || item->isPkgInfo();
 
     if ( item->isAttic() && col == PercentNumCol )
 	return QVariant();
@@ -1165,14 +1162,10 @@ void DirTreeModel::dataChangedNotify( DirInfo * dir )
 	QModelIndex topLeft	= modelIndex( dir, 0 );
 	QModelIndex bottomRight = createIndex( topLeft.row(), DataColumns::instance()->colCount() - 1, dir );
 
-#if (QT_VERSION < QT_VERSION_CHECK( 5, 1, 0))
-	emit dataChanged( topLeft, bottomRight );
-#else
 	QVector<int> roles;
 	roles << Qt::DisplayRole;
 
 	emit dataChanged( topLeft, bottomRight, roles );
-#endif
 	// logDebug() << "Data changed for " << dir << endl;
 
 	// If the view is still interested in this dir, it will fetch data, and
