@@ -52,6 +52,7 @@ FileInfo::FileInfo( DirTree    * tree,
     _isLocalFile   = true;
     _isSparseFile  = false;
     _isIgnored	   = false;
+    _hasUidGidPerm = false;
     _name	   = name ? name : "";
     _device	   = 0;
     _mode	   = 0;
@@ -85,6 +86,7 @@ FileInfo::FileInfo( const QString & filenameWithoutPath,
 
     _isLocalFile   = true;
     _isIgnored	   = false;
+    _hasUidGidPerm = true;
     _name	   = filenameWithoutPath;
 
     _device	   = statInfo->st_dev;
@@ -158,6 +160,9 @@ FileInfo::FileInfo( DirTree *	    tree,
 		    const QString & filenameWithoutPath,
 		    mode_t	    mode,
 		    FileSize	    size,
+                    bool            withUidGidPerm,
+                    uid_t           uid,
+                    gid_t           gid,
 		    time_t	    mtime,
 		    FileSize	    blocks,
 		    nlink_t	    links )
@@ -173,6 +178,7 @@ FileInfo::FileInfo( DirTree *	    tree,
     _name	   = filenameWithoutPath;
     _isLocalFile   = true;
     _isIgnored	   = false;
+    _hasUidGidPerm = withUidGidPerm;
     _device	   = 0;
     _mode	   = mode;
     _size	   = size;
@@ -181,8 +187,8 @@ FileInfo::FileInfo( DirTree *	    tree,
     _mtimeMonth    = -1;
     _allocatedSize = 0;
     _links	   = links;
-    _uid	   = 0;
-    _gid	   = 0;
+    _uid	   = uid;
+    _gid	   = gid;
     _magic	   = FileInfoMagic;
 
     if ( blocks < 0 )
@@ -530,16 +536,28 @@ bool FileInfo::isCached() const
 
 bool FileInfo::hasUid() const
 {
+    if ( _hasUidGidPerm )
+        return true;
+
     return ! isPkgInfo() && ! isCached();
 }
 
 
 bool FileInfo::hasGid() const
 {
+    if ( _hasUidGidPerm )
+        return true;
+
     return ! isPkgInfo() && ! isCached();
 }
 
 
+bool FileInfo::hasPermissions() const
+{
+    return _hasUidGidPerm;
+}
+
+
 QString FileInfo::userName() const
 {
     if ( ! hasUid() )
@@ -570,6 +588,9 @@ QString FileInfo::groupName() const
 
 QString FileInfo::symbolicPermissions() const
 {
+    if ( ! hasPermissions() )
+        return "";
+
     return symbolicMode( _mode,
 			 true ); // omitTypeForRegularFiles
 }
@@ -577,6 +598,9 @@ QString FileInfo::symbolicPermissions() const
 
 QString FileInfo::octalPermissions() const
 {
+    if ( ! hasPermissions() )
+        return "";
+
     return formatOctal( ALLPERMS & _mode );
 }
 
@@ -732,7 +756,7 @@ bool FileInfo::isDominant()
 
 QString QDirStat::baseName( const QString & fileName )
 {
-    QStringList segments = fileName.split( '/', QString::SkipEmptyParts );
+    QStringList segments = fileName.split( '/', Qt::SkipEmptyParts );
     return segments.isEmpty() ? "" : segments.last();
 }
 
