@@ -14,12 +14,13 @@
 #include <sys/types.h>  // dev_t, mode_t, nlink_t
 #include <sys/stat.h>   // S_ISDIR() etc.
 
-#include <QTextStream>
 #include <QList>
 
+#include "LogStream.h"
 #include "FileSize.h"
 #include "Logger.h"
 
+
 // The size of a standard disk block.
 //
 // Notice that this is different from st_blksize in the struct that the stat()
@@ -109,6 +110,9 @@ namespace QDirStat
 		  const QString & filenameWithoutPath,
 		  mode_t	  mode,
 		  FileSize	  size,
+                  bool            withUidGidPerm,
+                  uid_t           uid,
+                  gid_t           gid,
 		  time_t	  mtime,
 		  FileSize	  blocks = -1,
 		  nlink_t	  links	 = 1 );
@@ -180,7 +184,7 @@ namespace QDirStat
 	 * Very much like FileInfo::url(), but with "/<Files>" appended if this
 	 * is a dot entry. Useful for debugging.
 	 *
-	 * Notice: You can simply use the QTextStream operator<< to output
+	 * Notice: You can simply use the LogStream operator<< to output
 	 * exactly this:
 	 *
 	 * logDebug() << "Found fileInfo " << info << endl;
@@ -256,6 +260,14 @@ namespace QDirStat
 	 **/
 	bool hasGid() const;
 
+	/**
+	 * Return 'true' if this FileInfo has known permissions.
+	 *
+	 * It might not have that information e.g. if it was read from a cache
+	 * file.
+	 **/
+        bool hasPermissions() const;
+
 	/**
 	 * File permissions formatted like in "ls -l", i.e. "-rwxrwxrwx",
 	 * "drwxrwxrwx"
@@ -946,9 +958,10 @@ namespace QDirStat
 
 	short		_magic;			// magic number to detect if this object is valid
 	QString		_name;			// the file name (without path!)
-	bool		_isLocalFile  :1;	// flag: local or remote file?
-	bool		_isSparseFile :1;	// (cache) flag: sparse file (file with "holes")?
-	bool		_isIgnored    :1;	// flag: ignored by rule?
+	bool		_isLocalFile   :1;	// flag: local or remote file?
+	bool		_isSparseFile  :1;	// (cache) flag: sparse file (file with "holes")?
+	bool		_isIgnored     :1;	// flag: ignored by rule?
+        bool            _hasUidGidPerm :1;      // flag: has UID / GID / permissions?
 	dev_t		_device;		// device this object resides on
 	mode_t		_mode;			// file permissions + object type
 	nlink_t		_links;			// number of links
@@ -998,7 +1011,8 @@ namespace QDirStat
     /**
      * Print the debugUrl() of a FileInfo in a debug stream.
      **/
-    inline QTextStream & operator<< ( QTextStream & stream, const FileInfo * info )
+    inline LogStream & operator<< ( LogStream      & stream,
+                                    const FileInfo * info )
     {
 	if ( info )
 	{
