@@ -51,9 +51,6 @@ void FilesystemsWindow::populate()
     {
 	CHECK_PTR( mountPoint);
 
-        if ( mountPoint->isUnmountedAutofs() )
-            continue;
-
 	FilesystemItem * item = new FilesystemItem( mountPoint, _ui->fsTree );
 	CHECK_NEW( item );
 
@@ -103,18 +100,14 @@ void FilesystemsWindow::clear()
 void FilesystemsWindow::initWidgets()
 {
     QStringList headers;
-    headers << tr( "Device" )
+    headers << tr( "Device"      )
 	    << tr( "Mount Point" )
-	    << tr( "Type" );
-
-    if ( MountPoints::hasSizeInfo() )
-    {
-	headers << tr( "Size"	  )
-		<< tr( "Used"	  )
-		<< tr( "Reserved" )
-		<< tr( "Free"	  )
-		<< tr( "Free %"	  );
-    }
+	    << tr( "Type"        )
+            << tr( "Size"	 )
+            << tr( "Used"	 )
+            << tr( "Reserved"    )
+            << tr( "Free"	 )
+            << tr( "Free %"	 );
 
     _ui->fsTree->setHeaderLabels( headers );
     _ui->fsTree->header()->setStretchLastSection( false );
@@ -195,8 +188,22 @@ FilesystemItem::FilesystemItem( MountPoint  * mountPoint,
     _isReadOnly	    ( mountPoint->isReadOnly()	    )
 {
     QString blanks = QString( 4, ' ' );
+    QString dev    = _device;
 
-    setText( FS_DeviceCol,    _device + blanks );
+    if ( dev.startsWith( "/dev/mapper/luks-" ) )
+    {
+        // Cut off insanely long generated device mapper LUKS names
+
+        int limit = sizeof( "/dev/mapper/luks-010203" ) - 1;
+
+        if ( dev.size() > limit )
+        {
+            dev = dev.left( limit ) + "...";
+            setToolTip( FS_DeviceCol, _device );
+        }
+    }
+
+    setText( FS_DeviceCol,    dev + blanks );
     setText( FS_MountPathCol, _mountPath );
     setText( FS_TypeCol,      _fsType	 );
 
