@@ -8,14 +8,51 @@
 
 #include <QObject>
 #include <QDateTime>
-#include <QTextStream>
 
 #include "FormatUtil.h"
+#include "Exception.h"
 #include "BrokenLibc.h"     // ALLPERMS
+#include "Settings.h"
+#include "SettingsHelpers.h"
 
 using namespace QDirStat;
 
 
+FormatOptions * FormatOptions::_instance = 0;
+
+FormatOptions * FormatOptions::instance()
+{
+    if ( ! _instance )
+    {
+        _instance = new FormatOptions();
+        CHECK_NEW( _instance );
+    }
+
+    return _instance;
+}
+
+
+FormatOptions::FormatOptions()
+{
+    useIsoDate = false;
+
+    readSettings();
+}
+
+
+void FormatOptions::readSettings()
+{
+    Settings settings;
+    settings.beginGroup( "FormatOptions" );
+
+    useIsoDate = settings.value( "UseIsoDate", false ).toBool();
+
+    settings.endGroup();
+}
+
+
+
+
 QString QDirStat::formatSize( FileSize lSize )
 {
     return formatSize( lSize, 1 );
@@ -108,8 +145,27 @@ QString QDirStat::formatTime( time_t rawTime )
     if ( rawTime == (time_t) 0 )
 	return "";
 
-    QDateTime time = QDateTime::fromTime_t( rawTime );
-    return time.toString( Qt::DefaultLocaleShortDate );
+    QDateTime time = QDateTime::fromSecsSinceEpoch( rawTime );
+
+    QString ret;
+
+    if ( FormatOptions::instance()->useIsoDate )
+    {
+        // "2024-12-28T17:38"
+        ret = time.toString( Qt::ISODate );
+
+        // Get rid of that moronic 'T' to get "2024-12-28  17:38"
+        ret.replace( "T", "  " );
+    }
+    else
+    {
+        // We'll need this a lot, so let's cache the result of this fugly expression
+        static QString timeFormat( QLocale::system().dateFormat( QLocale::ShortFormat ) );
+
+        ret = time.toString( timeFormat );
+    }
+
+    return ret;
 }
 
 
