@@ -11,10 +11,11 @@
 #define MainWindow_h
 
 #include <QMainWindow>
-#include <QString>
+#include <QActionGroup>
 #include <QElapsedTimer>
-#include <QTimer>
 #include <QPointer>
+#include <QString>
+#include <QTimer>
 
 #include "ui_main-window.h"
 #include "FileAgeStatsWindow.h"
@@ -281,12 +282,6 @@ protected slots:
      **/
     void showTreemapView();
 
-    /**
-     * Switch between showing the treemap view beside the file directory
-     * or below it, depending on the corresponding action.
-     **/
-    void treemapAsSidePanel();
-
     /**
      * Notification that a cleanup action was started.
      **/
