@@ -8,7 +8,7 @@
 
 
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QFileInfo>
 
 #include "MountPoints.h"
@@ -29,10 +29,8 @@ MountPoint::MountPoint( const QString & device,
     _device( device ),
     _path( path ),
     _filesystemType( filesystemType ),
-    _isDuplicate( false )
-#if HAVE_Q_STORAGE_INFO
-    , _storageInfo( 0 )
-#endif
+    _isDuplicate( false ),
+    _storageInfo( 0 )
 {
     _mountOptions = mountOptions.split( "," );
 }
@@ -40,10 +38,8 @@ MountPoint::MountPoint( const QString & device,
 
 MountPoint::~MountPoint()
 {
-#if HAVE_Q_STORAGE_INFO
     if ( _storageInfo )
         delete _storageInfo;
-#endif
 }
 
 
@@ -119,8 +115,6 @@ bool MountPoint::isSnapPackage() const
 }
 
 
-#if HAVE_Q_STORAGE_INFO
-
 QStorageInfo * MountPoint::storageInfo()
 {
     if ( ! _storageInfo )
@@ -136,12 +130,6 @@ QStorageInfo * MountPoint::storageInfo()
 }
 
 
-bool MountPoint::hasSizeInfo() const
-{
-    return true;
-}
-
-
 FileSize MountPoint::totalSize()
 {
     return storageInfo()->bytesTotal();
@@ -171,20 +159,6 @@ FileSize MountPoint::freeSizeForRoot()
     return storageInfo()->bytesFree();
 }
 
-#else  // ! HAVE_Q_STORAGE_INFO
-
-// Qt before 5.4 does not have QStorageInfo,
-// and statfs() is Linux-specific (not POSIX).
-
-bool	 MountPoint::hasSizeInfo() const { return false; }
-FileSize MountPoint::totalSize()	 { return -1; }
-FileSize MountPoint::usedSize()		 { return -1; }
-FileSize MountPoint::reservedSize()	 { return -1; }
-FileSize MountPoint::freeSizeForUser()	 { return -1; }
-FileSize MountPoint::freeSizeForRoot()   { return -1; }
-
-#endif // ! HAVE_Q_STORAGE_INFO
-
 
 
 
@@ -221,8 +195,9 @@ void MountPoints::init()
     _mountPointList.clear();
     _mountPointMap.clear();
     _isPopulated     = false;
-    _hasBtrfs	     = false;
     _checkedForBtrfs = false;
+    _hasBtrfs	     = false;
+    _hasNtfs         = false;
 }
 
 
@@ -261,7 +236,7 @@ MountPoint * MountPoints::findNearestMountPoint( const QString & startPath )
 
     if ( ! mountPoint )
     {
-	QStringList pathComponents = startPath.split( "/", QString::SkipEmptyParts );
+	QStringList pathComponents = startPath.split( "/", Qt::SkipEmptyParts );
 
 	while ( ! mountPoint && ! pathComponents.isEmpty() )
 	{
@@ -308,6 +283,14 @@ bool MountPoints::hasBtrfs()
 }
 
 
+bool MountPoints::hasNtfs()
+{
+    instance()->ensurePopulated();
+
+    return _instance->_hasNtfs;
+}
+
+
 void MountPoints::ensurePopulated()
 {
     if ( _isPopulated )
@@ -322,13 +305,9 @@ void MountPoints::ensurePopulated()
 
 #endif
 
-#if HAVE_Q_STORAGE_INFO
-
     if ( ! _isPopulated )
         readStorageInfo();
 
-#endif
-
     _isPopulated = true; // don't try more than once
     // dumpNormalMountPoints();
 }
@@ -351,11 +330,12 @@ bool MountPoints::read( const QString & filename )
     int lineNo = 0;
     int count  = 0;
     QString line = in.readLine();
+    const QRegularExpression whitespace( "\\s+" );
 
     while ( ! line.isNull() ) // in.atEnd() always returns true for /proc/*
     {
 	++lineNo;
-	QStringList fields = line.split( QRegExp( "\\s+" ), QString::SkipEmptyParts );
+	QStringList fields = line.split( whitespace, Qt::SkipEmptyParts );
 
 	if ( fields.isEmpty() ) // allow empty lines
 	    continue;
@@ -439,8 +419,6 @@ void MountPoints::add( MountPoint * mountPoint )
 }
 
 
-#if HAVE_Q_STORAGE_INFO
-
 bool MountPoints::readStorageInfo()
 {
     findNtfsDevices();
@@ -480,8 +458,6 @@ bool MountPoints::readStorageInfo()
     }
 }
 
-#endif // HAVE_Q_STORAGE_INFO
-
 
 bool MountPoints::checkForBtrfs()
 {
@@ -525,18 +501,31 @@ void MountPoints::findNtfsDevices()
                                           false );      // ignoreErrCode
     if ( exitCode == 0 )
     {
-        QStringList lines = output.split( "\n" )
-            .filter( QRegExp( "\\s+ntfs", Qt::CaseInsensitive ) );
+        QStringList lines = output.split( QChar( '\n' ) );
 
         foreach ( QString line, lines )
         {
-            QString device = "/dev/" + line.split( QRegExp( "\\s+" ) ).first();
-            logDebug() << "NTFS on " << device << endl;
-            _ntfsDevices << device;
+            // Sample output:
+            //
+            // sda
+            // sda0 swap
+            // sda1 ext4
+            // sda2 ntfs
+
+            QString device = "/dev/" + line.section( QChar( ' ' ), 0, 0 );
+            QString fstype = line.section( QChar( ' ' ), 1 );
+
+            if ( fstype.toLower() == "ntfs" )
+            {
+                logDebug() << "NTFS on " << device << endl;
+                _ntfsDevices << device;
+            }
         }
     }
 
-    if ( _ntfsDevices.isEmpty() )
+    _hasNtfs = ! _ntfsDevices.isEmpty();
+
+    if ( ! _hasNtfs )
         logDebug() << "No NTFS devices found" << endl;
 }
 
@@ -582,10 +571,3 @@ void MountPoints::reload()
     instance()->clear();
     instance()->ensurePopulated();
 }
-
-
-#if HAVE_Q_STORAGE_INFO
-  bool MountPoints::hasSizeInfo() { return true; }
-#else
-  bool MountPoints::hasSizeInfo() { return false; }
-#endif
