@@ -10,20 +10,13 @@
 #define MountPoints_h
 
 
-#include <QString>
-#include <QStringList>
 #include <QList>
 #include <QMap>
-#include <QTextStream>
-
-#if (QT_VERSION < QT_VERSION_CHECK( 5, 4, 0 ))
-#  define HAVE_Q_STORAGE_INFO 0
-typedef void * QStorageInfo;
-#else
-#  define HAVE_Q_STORAGE_INFO 1
-#  include <QStorageInfo>
-#endif
+#include <QStorageInfo>
+#include <QString>
+#include <QStringList>
 
+#include "LogStream.h"
 #include "FileSize.h"
 
 
@@ -133,12 +126,6 @@ namespace QDirStat
 	 **/
 	void setDuplicate( bool dup = true ) { _isDuplicate = dup; }
 
-	/**
-	 * Return 'true' if size information for this mount point is available.
-	 * This may depend on the build OS and the Qt version.
-	 **/
-	bool hasSizeInfo() const;
-
 	/**
 	 * Total size of the filesystem of this mount point.
 	 * This returns -1 if no size information is available.
@@ -172,12 +159,10 @@ namespace QDirStat
 
     protected:
 
-#if HAVE_Q_STORAGE_INFO
         /**
          * Lazy access to the QStorageInfo for this mount.
          **/
         QStorageInfo * storageInfo();
-#endif
 
 	QString	    _device;
 	QString	    _path;
@@ -185,9 +170,7 @@ namespace QDirStat
 	QStringList _mountOptions;
 	bool	    _isDuplicate;
 
-#if HAVE_Q_STORAGE_INFO
 	QStorageInfo * _storageInfo;
-#endif
     }; // class MountPoint
 
 
@@ -242,6 +225,11 @@ namespace QDirStat
 	 **/
 	static bool hasBtrfs();
 
+        /**
+	 * Return 'true' if any mount point has filesystem type "ntfs".
+         **/
+        static bool hasNtfs();
+
 	/**
 	 * Ensure the mount points are populated with the content of
 	 * /proc/mounts, falling back to /etc/mtab if /proc/mounts cannot be
@@ -270,12 +258,6 @@ namespace QDirStat
 	 **/
 	static void dumpNormalMountPoints();
 
-	/**
-	 * Return 'true' if size information for mount points is available.
-	 * This may depend on the build OS and the Qt version.
-	 **/
-	static bool hasSizeInfo();
-
         /**
          * Clear all information and reload it from disk.
          * NOTICE: This invalidates ALL MountPoint pointers!
@@ -308,14 +290,11 @@ namespace QDirStat
 	 **/
 	bool read( const QString & filename );
 
-#if HAVE_Q_STORAGE_INFO
-
         /**
          * Fallback method if neither /proc/mounts nor /etc/mtab is available:
          * Try using QStorageInfo. Return 'true' if any mount point was found.
          **/
         bool readStorageInfo();
-#endif
 
         /**
          * Post-process a mount point and add it to the internal list and map.
@@ -354,13 +333,14 @@ namespace QDirStat
 	QMap<QString, MountPoint *> _mountPointMap;
         QStringList                 _ntfsDevices;
 	bool			    _isPopulated;
-	bool			    _hasBtrfs;
 	bool			    _checkedForBtrfs;
+	bool			    _hasBtrfs;
+        bool                        _hasNtfs;
 
     }; // class MountPoints
 
 
-    inline QTextStream & operator<< ( QTextStream & stream, MountPoint * mp )
+    inline LogStream & operator<< ( LogStream & stream, MountPoint * mp )
     {
 	if ( mp )
 	{
