@@ -7,13 +7,12 @@
  */
 
 
-#include <QPushButton>
 #include <QDir>
 #include <QFileSystemModel>
+#include <QLineEdit>
+#include <QPushButton>
 #include <QTimer>
 
-#include "Qt4Compat.h"
-
 #include "OpenDirDialog.h"
 #include "MountPoints.h"
 #include "ExistingDirCompleter.h"
@@ -39,6 +38,7 @@
 using namespace QDirStat;
 
 
+bool OpenDirDialog::_firstRun         = true;
 bool OpenDirDialog::_crossFilesystems = false;
 
 
@@ -55,6 +55,7 @@ OpenDirDialog::OpenDirDialog( QWidget * parent ):
 
     initPathComboBox();
     initDirTree();
+    readSettings();
 
     _ui->crossFilesystemsCheckBox->setChecked( _crossFilesystems );
 
@@ -62,7 +63,6 @@ OpenDirDialog::OpenDirDialog( QWidget * parent ):
     CHECK_PTR( _okButton );
 
     initConnections();
-    readSettings();
 
     _ui->pathComboBox->setFocus();
     QTimer::singleShot( 200, this, SLOT( initialSelection() ) );
@@ -77,7 +77,7 @@ OpenDirDialog::~OpenDirDialog()
 
 void OpenDirDialog::initPathComboBox()
 {
-    qEnableClearButton( _ui->pathComboBox );
+    _ui->pathComboBox->lineEdit()->setClearButtonEnabled( true );
 
 #if USE_COMPLETER
     QCompleter * completer = new ExistingDirCompleter( this );
@@ -187,7 +187,7 @@ void OpenDirDialog::setPath( const QString & path )
     // so any change would not become visible in the tree.
 
     populatePathComboBox( path );
-    qSetComboBoxText( _ui->pathComboBox, path );
+    _ui->pathComboBox->setCurrentText( path );
     QModelIndex index = _filesystemModel->index( path );
     _ui->dirTreeView->setCurrentIndex( index );
     _ui->dirTreeView->scrollTo( index );
@@ -257,7 +257,7 @@ void OpenDirDialog::treeSelection( const QModelIndex & newCurrentItem,
 
 void OpenDirDialog::populatePathComboBox( const QString & fullPath )
 {
-    QStringList pathComponents = fullPath.split( "/", QString::SkipEmptyParts );
+    QStringList pathComponents = fullPath.split( "/", Qt::SkipEmptyParts );
 
     _ui->pathComboBox->clear();
     _ui->pathComboBox->addItem( "/" );
@@ -273,7 +273,7 @@ void OpenDirDialog::populatePathComboBox( const QString & fullPath )
 
 void OpenDirDialog::goUp()
 {
-    QStringList pathComponents = selectedPath().split( "/", QString::SkipEmptyParts );
+    QStringList pathComponents = selectedPath().split( "/", Qt::SkipEmptyParts );
 
     if ( ! pathComponents.isEmpty() )
         pathComponents.removeLast();
@@ -295,17 +295,22 @@ void OpenDirDialog::readSettings()
     Settings settings;
     // logDebug() << endl;
 
-    // Initialize the static _crossFilesystems flag from the corresponding
-    // setting from the config dialog
+    if ( _firstRun )
+    {
+        // Initialize the static _crossFilesystems flag from the corresponding
+        // setting from the config dialog
 
-    settings.beginGroup( "DirectoryTree" );
-    _crossFilesystems = settings.value( "CrossFilesystems", false ).toBool();
-    settings.endGroup();
+        settings.beginGroup( "DirectoryTree" );
+        _crossFilesystems = settings.value( "CrossFilesystems", false ).toBool();
+        settings.endGroup();
+
+        _firstRun = false;
+    }
 
     readWindowSettings( this, "OpenDirDialog" );
 
     settings.beginGroup( "OpenDirDialog" );
-    QByteArray mainSplitterState = settings.value( "MainSplitter" , QByteArray() ).toByteArray();
+    QByteArray mainSplitterState = settings.value( "MainSplitter", QByteArray() ).toByteArray();
     settings.endGroup();
 
     if ( ! mainSplitterState.isNull() )
