@@ -7,8 +7,6 @@
  */
 
 
-#include "Qt4Compat.h"
-
 #include "OpenPkgDialog.h"
 #include "Logger.h"
 #include "Exception.h"
@@ -25,7 +23,7 @@ OpenPkgDialog::OpenPkgDialog( QWidget * parent ):
 
     CHECK_NEW( _ui );
     _ui->setupUi( this );
-    qEnableClearButton( _ui->pkgPatternField );
+    _ui->pkgPatternField->setClearButtonEnabled( true );
     _ui->pkgPatternField->setFocus();
 }
 
