@@ -7,6 +7,8 @@
  */
 
 
+#include <QRegularExpression>
+
 #include "PkgReader.h"
 #include "PkgQuery.h"
 #include "PkgManager.h"
@@ -17,10 +19,10 @@
 #include "Logger.h"
 #include "Exception.h"
 
-#define VERBOSE_MISSING_PACKAGED_FILES  0
-
 using namespace QDirStat;
 
+bool PkgReader::_verboseMissingPkgFiles = false;
+
 
 PkgReader::PkgReader( DirTree * tree ):
     _tree( tree ),
@@ -219,7 +221,7 @@ void PkgReader::createAsyncPkgReadJobs()
 
     foreach ( PkgInfo * pkg, _pkgList )
     {
-	Process * process = createReadFileListProcess( pkg );
+	QProcess * process = createReadFileListProcess( pkg );
 
 	if ( process )
 	{
@@ -234,7 +236,7 @@ void PkgReader::createAsyncPkgReadJobs()
 }
 
 
-Process * PkgReader::createReadFileListProcess( PkgInfo * pkg )
+QProcess * PkgReader::createReadFileListProcess( PkgInfo * pkg )
 {
     CHECK_PTR( pkg );
     CHECK_PTR( pkg->pkgManager() );
@@ -247,13 +249,13 @@ Process * PkgReader::createReadFileListProcess( PkgInfo * pkg )
 	return 0;
     }
 
-    QStringList args	 = command.split( QRegExp( "\\s+" ) );
+    QStringList args	 = command.split( QRegularExpression( "\\s+" ) );
     QString	program	 = args.takeFirst();
 
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
     env.insert( "LANG", "C" ); // Prevent output in translated languages
 
-    Process * process = new Process();
+    QProcess * process = new QProcess();
     process->setProgram( program );
     process->setArguments( args );
     process->setProcessEnvironment( env );
@@ -270,8 +272,9 @@ void PkgReader::readSettings()
     Settings settings;
     settings.beginGroup( "Pkg" );
 
-    _maxParallelProcesses = settings.value( "MaxParallelProcesses",  6 ).toInt();
-    _minCachePkgListSize  = settings.value( "MinCachePkgListSize", 200 ).toInt();
+    _maxParallelProcesses   = settings.value( "MaxParallelProcesses"  ,  6    ).toInt();
+    _minCachePkgListSize    = settings.value( "MinCachePkgListSize"   , 200   ).toInt();
+    _verboseMissingPkgFiles = settings.value( "VerboseMissingPkgFiles", false ).toBool();
 
     settings.endGroup();
 }
@@ -282,8 +285,9 @@ void PkgReader::writeSettings()
     Settings settings;
     settings.beginGroup( "Pkg" );
 
-    settings.setValue( "MaxParallelProcesses", _maxParallelProcesses );
-    settings.setValue( "MinCachePkgListSize" , _minCachePkgListSize  );
+    settings.setValue( "MaxParallelProcesses"  , _maxParallelProcesses   );
+    settings.setValue( "MinCachePkgListSize"   , _minCachePkgListSize    );
+    settings.setValue( "VerboseMissingPkgFiles", _verboseMissingPkgFiles );
 
     settings.endGroup();
 }
@@ -376,7 +380,7 @@ void PkgReadJob::addFile( const QString & fileListPath )
 
     // logDebug() << "Adding " << fileListPath << " to " << _pkg << endl;
 
-    QStringList remaining = fileListPath.split( "/", QString::SkipEmptyParts );
+    QStringList remaining = fileListPath.split( "/", Qt::SkipEmptyParts );
     QStringList currentPath;
     DirInfo *	parent = _pkg;
 
@@ -393,16 +397,18 @@ void PkgReadJob::addFile( const QString & fileListPath )
 
 	    if ( ! newParent )
 	    {
-#if VERBOSE_MISSING_PACKAGED_FILES
-                // Don't report a directory read error here:
-                // A file that belongs to the package should be there, but is not.
-                // The user might intentionally have deleted it for some reason;
-                // just report that in the log.
-                //
-		// parent->setReadState( DirError );
+                if ( PkgReader::verboseMissingPkgFiles() )
+                {
+                    // Don't report a directory read error here:
+                    // A file that belongs to the package should be there, but is not.
+                    // The user might intentionally have deleted it for some reason;
+                    // just report that in the log.
+                    //
+                    // parent->setReadState( DirError );
+
+                    logWarning() << _pkg << ": missing: " << fileListPath << endl;
+                }
 
-                logWarning() << _pkg << ": missing: " << fileListPath << endl;
-#endif
 		return;
 	    }
 
@@ -524,9 +530,9 @@ struct stat * PkgReadJob::lstat( const QString & path )
 
 
 
-AsyncPkgReadJob::AsyncPkgReadJob( DirTree * tree,
-				  PkgInfo * pkg,
-				  Process * readFileListProcess ):
+AsyncPkgReadJob::AsyncPkgReadJob( DirTree  * tree,
+				  PkgInfo  * pkg,
+				  QProcess * readFileListProcess ):
     PkgReadJob( tree, pkg ),
     _readFileListProcess( readFileListProcess )
 {
@@ -545,7 +551,7 @@ void AsyncPkgReadJob::readFileListFinished( int			 exitCode,
     CHECK_PTR( _pkg );
     CHECK_PTR( _pkg->pkgManager() );
 
-    bool ok	   = true;
+    bool ok = true;
 
     if ( exitStatus != QProcess::NormalExit )
     {
