@@ -118,18 +118,18 @@ FileInfo * QDirStatApp::root() const
 }
 
 
-FileInfo * QDirStatApp::selectedDir() const
+FileInfo * QDirStatApp::selectedDirInfo() const
 {
     FileInfoSet selectedItems = selectionModel()->selectedItems();
     FileInfo * sel = selectedItems.first();
 
-    return sel && sel->isDir() ? sel : 0;
+    return sel && sel->isDirInfo() ? sel : 0;
 }
 
 
-FileInfo * QDirStatApp::selectedDirOrRoot() const
+FileInfo * QDirStatApp::selectedDirInfoOrRoot() const
 {
-    FileInfo * sel = selectedDir();
+    FileInfo * sel = selectedDirInfo();
 
     return sel ? sel : root();
 }
