@@ -24,7 +24,6 @@
 
 
 using std::cerr;
-using std::endl;
 using namespace QDirStat;
 
 
@@ -112,7 +111,7 @@ PkgInfoList RpmPkgManager::parsePkgList( const QString & output )
     {
 	if ( ! line.isEmpty() )
 	{
-	    QStringList fields = line.split( " | ", QString::KeepEmptyParts );
+	    QStringList fields = line.split( " | ", Qt::KeepEmptyParts );
 
 	    if ( fields.size() != 3 )
 		logError() << "Invalid rpm -qa output: " << line << "\n" << endl;
@@ -246,7 +245,7 @@ void RpmPkgManager::rebuildRpmDbWarning()
 
     if ( ! issuedWarning )
     {
-	cerr << "WARNING: rpm is very slow. Run	  sudo rpm --rebuilddb\n" << endl;
+	cerr << "WARNING: rpm is very slow. Run	  sudo rpm --rebuilddb\n" << std::endl;
 	logWarning()  << "rpm is very slow. Run	  sudo rpm --rebuilddb"	  << endl;
     }
 
