@@ -200,11 +200,7 @@ void SelectionModel::setCurrentItem( FileInfo * item, bool select )
     }
     else
     {
-#if (QT_VERSION < QT_VERSION_CHECK( 5, 0, 0 ))
-	setCurrentIndex( QModelIndex(), Current );
-#else
 	clearCurrentIndex();
-#endif
     }
 }
 
@@ -264,7 +260,7 @@ void SelectionModel::deletingChildNotify( FileInfo * deletedChild )
     _selectedItemsDirty = true;
     _selectedItems.clear();
 
-    if ( _currentItem->isInSubtree( deletedChild ) )
+    if ( _currentItem && _currentItem->isInSubtree( deletedChild ) )
 	setCurrentItem( 0 );
 }
 
