@@ -12,7 +12,6 @@
 
 #include "SizeColDelegate.h"
 #include "DirTreeModel.h"
-#include "Qt4Compat.h"
 #include "Exception.h"
 #include "FileInfo.h"
 #include "Logger.h"
@@ -33,7 +32,7 @@ SizeColDelegate::SizeColDelegate( QTreeView * treeView ):
     _treeView( treeView ),
     _model( 0 )
 {
-    QColor background = qAppPalette().color( QPalette::Active, QPalette::Base );
+    QColor background = QGuiApplication::palette().color( QPalette::Active, QPalette::Base );
     _usingDarkTheme = background.lightness() < 128; // 0 (black) .. 255 (white)
 }
 
@@ -93,7 +92,7 @@ void SizeColDelegate::paint( QPainter		        * painter,
                     // to reserve some space for the allocated size.
 
                     QFontMetrics fontMetrics( option.font );
-                    int allocWidth = fontMetrics.width( allocText );
+                    int allocWidth = fontMetrics.horizontalAdvance( allocText );
                     rect.setWidth( rect.width() - allocWidth );
 
                     painter->setPen( textColor );
@@ -141,7 +140,7 @@ QSize SizeColDelegate::sizeHint( const QStyleOptionViewItem & option,
             {
                 QString text = _model->data( index, Qt::DisplayRole ).toString();
                 QFontMetrics fontMetrics( option.font );
-                int width  = fontMetrics.width( text );
+                int width  = fontMetrics.horizontalAdvance( text );
                 int height = fontMetrics.height();
                 QSize size( width  + MARGIN_RIGHT + MARGIN_LEFT,
                             height + MARGIN_TOP   + MARGIN_BOTTOM );
