@@ -15,8 +15,10 @@
 #include <sys/stat.h>   // lstat()
 #include <sys/types.h>
 
+#include <QProcess>
+#include <QRegularExpression>
+
 #include "SysUtil.h"
-#include "Process.h"
 #include "DirSaver.h"
 #include "Logger.h"
 #include "Exception.h"
@@ -58,7 +60,7 @@ QString SysUtil::runCommand( const QString & commandLine,
     if ( exitCode_ret )
 	*exitCode_ret = -1;
 
-    QStringList args = commandLine.split( QRegExp( "\\s+" ) );
+    QStringList args = commandLine.split( QRegularExpression( "\\s+" ) );
 
     if ( args.size() < 1 )
     {
@@ -93,7 +95,7 @@ QString SysUtil::runCommand( const QString &	 command,
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
     env.insert( "LANG", "C" ); // Prevent output in translated languages
 
-    Process process;
+    QProcess process;
     process.setProgram( command );
     process.setArguments( args );
     process.setProcessEnvironment( env );
@@ -151,7 +153,7 @@ void SysUtil::openInBrowser( const QString & url )
 {
     logDebug() << "Opening URL " << url << endl;
 
-    Process::startDetached( "/usr/bin/xdg-open", QStringList() << url );
+    QProcess::startDetached( "/usr/bin/xdg-open", QStringList() << url );
 }
 
 
@@ -203,7 +205,7 @@ bool SysUtil::isBrokenSymLink( const QString & path )
 
     // Start from the symlink's parent directory
 
-    QStringList pathSegments = path.split( '/', QString::SkipEmptyParts );
+    QStringList pathSegments = path.split( '/', Qt::SkipEmptyParts );
     pathSegments.removeLast(); // We already know it's a symlink, not a directory
     QString parentPath = QString( path.startsWith( "/" ) ? "/" : "" ) + pathSegments.join( "/" );
     DirSaver dir( parentPath );
