@@ -115,9 +115,7 @@ void TreemapTile::init()
 
     setFlags( ItemIsSelectable );
     _highlighter = 0;
-
-    if ( ( _orig->isDir() && _orig->totalSubDirs() == 0 ) || _orig->isDotEntry() )
-        setAcceptHoverEvents( true );
+    setAcceptHoverEvents( true );
 
     if ( ! _parentTile )
 	_parentView->scene()->addItem( this );
@@ -655,7 +653,7 @@ void TreemapTile::mousePressEvent( QGraphicsSceneMouseEvent * event )
 	    _parentView->setCurrentItem( this );
 	    break;
 
-	case Qt::MidButton:
+	case Qt::MiddleButton:
             // logDebug() << "Middle click on " << _orig << endl;
 
             // Handle item selection (with or without Ctrl) ourselves here;
@@ -728,7 +726,7 @@ void TreemapTile::mouseDoubleClickEvent( QGraphicsSceneMouseEvent * event )
 	    _parentView->zoomIn();
 	    break;
 
-	case Qt::MidButton:
+	case Qt::MiddleButton:
 	    logDebug() << "Zooming treemap out" << endl;
 	    _parentView->zoomOut();
 	    break;
