@@ -10,10 +10,14 @@
 #include <iostream>	// cerr
 
 #include <QApplication>
+#include <QProcess>
+#include <QProcessEnvironment>
+
 #include "QDirStatApp.h"
 #include "MainWindow.h"
 #include "DirTreeModel.h"
 #include "Settings.h"
+#include "Translator.h"
 #include "Logger.h"
 #include "Exception.h"
 #include "Version.h"
@@ -34,6 +38,7 @@ void usage( const QStringList & argList )
 	 << "  " << progName << " unpkg:/dir\n"
 	 << "  " << progName << " --dont-ask|-d\n"
 	 << "  " << progName << " --cache|-c <cache-file-name>\n"
+	 << "  " << progName << " --fake-translations\n"
 	 << "  " << progName << " --help|-h\n"
 	 << "\n"
 	 << "\n"
@@ -61,10 +66,10 @@ void logVersion()
               << " built with Qt " << QT_VERSION_STR
               << endl;
 
-#if (QT_VERSION < QT_VERSION_CHECK( 5, 2, 0 ))
+#if (QT_VERSION < QT_VERSION_CHECK( 6, 6, 0 ))
     logWarning() << "WARNING: You are using Qt " << QT_VERSION_STR
                  << ". This may or may not work." << endl;
-    logWarning() << "The supported Qt version for QDirStat is Qt 5.2 or newer." << endl;
+    logWarning() << "The supported Qt version for QDirStat is Qt 6.10 or newer." << endl;
 #endif
 }
 
@@ -93,6 +98,20 @@ bool commandLineSwitch( const QString & longName,
 }
 
 
+void logQtEnv()
+{
+    QStringList env( QProcess::systemEnvironment() );
+
+    for ( const QString & envVar: env )
+    {
+        if ( envVar.startsWith( "QT" ) )
+        {
+            logDebug() << envVar << endl;
+        }
+    }
+}
+
+
 int main( int argc, char *argv[] )
 {
     Logger logger( "/tmp/qdirstat-$USER", "qdirstat.log" );
@@ -105,6 +124,13 @@ int main( int argc, char *argv[] )
     QApplication qtApp( argc, argv);
     QStringList argList = QCoreApplication::arguments();
     argList.removeFirst(); // Remove program name
+    logQtEnv();
+
+    if ( commandLineSwitch( "--fake-translations", "--xixo", argList ) )
+        Translator::useFakeTranslations();
+
+    Translator translator( "qdirstat" );
+    qApp->installTranslator( &translator );
 
     MainWindow * mainWin = new MainWindow();
     CHECK_PTR( mainWin );
